@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -41,12 +41,10 @@ class PimCommon::AutoCorrectionWidgetPrivate
 {
 public:
     AutoCorrectionWidgetPrivate()
-        : ui(new Ui::AutoCorrectionWidget),
-          mAutoCorrection(nullptr),
-          mWasChanged(false)
+        : ui(new Ui::AutoCorrectionWidget)
     {
-
     }
+
     ~AutoCorrectionWidgetPrivate()
     {
         delete ui;
@@ -57,14 +55,14 @@ public:
     QSet<QString> m_upperCaseExceptions;
     QSet<QString> m_twoUpperLetterExceptions;
     QHash<QString, QString> m_autocorrectEntries;
-    Ui::AutoCorrectionWidget *ui;
-    AutoCorrection *mAutoCorrection;
-    bool mWasChanged;
+    Ui::AutoCorrectionWidget *ui = nullptr;
+    AutoCorrection *mAutoCorrection = nullptr;
+    bool mWasChanged = false;
 };
 
-AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent) :
-    QWidget(parent),
-    d(new PimCommon::AutoCorrectionWidgetPrivate)
+AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
+    : QWidget(parent)
+    , d(new PimCommon::AutoCorrectionWidgetPrivate)
 {
     d->ui->setupUi(this);
 
@@ -74,18 +72,18 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent) :
     d->ui->add1->setEnabled(false);
     d->ui->add2->setEnabled(false);
 
-    connect(d->ui->autoChangeFormat, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->autoFormatUrl, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->upperCase, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->upperUpper, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->ignoreDoubleSpace, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->autoReplaceNumber, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->capitalizeDaysName, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->advancedAutocorrection, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->enabledAutocorrection, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
+    connect(d->ui->autoChangeFormat, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->autoFormatUrl, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->upperCase, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->upperUpper, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->ignoreDoubleSpace, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->autoReplaceNumber, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->capitalizeDaysName, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->advancedAutocorrection, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->enabledAutocorrection, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->typographicSingleQuotes, &QCheckBox::clicked, this, &AutoCorrectionWidget::enableSingleQuotes);
     connect(d->ui->typographicDoubleQuotes, &QCheckBox::clicked, this, &AutoCorrectionWidget::enableDoubleQuotes);
-    connect(d->ui->autoSuperScript, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
+    connect(d->ui->autoSuperScript, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->singleQuote1, &QPushButton::clicked, this, &AutoCorrectionWidget::selectSingleQuoteCharOpen);
     connect(d->ui->singleQuote2, &QPushButton::clicked, this, &AutoCorrectionWidget::selectSingleQuoteCharClose);
     connect(d->ui->singleDefault, &QPushButton::clicked, this, &AutoCorrectionWidget::setDefaultSingleQuotes);
@@ -106,14 +104,14 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent) :
     connect(d->ui->remove1, &QPushButton::clicked, this, &AutoCorrectionWidget::removeAbbreviationEntry);
     connect(d->ui->add2, &QPushButton::clicked, this, &AutoCorrectionWidget::addTwoUpperLetterEntry);
     connect(d->ui->remove2, &QPushButton::clicked, this, &AutoCorrectionWidget::removeTwoUpperLetterEntry);
-    connect(d->ui->typographicDoubleQuotes, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
-    connect(d->ui->typographicSingleQuotes, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
+    connect(d->ui->typographicDoubleQuotes, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
+    connect(d->ui->typographicSingleQuotes, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->abbreviationList, &PimCommon::AutoCorrectionListWidget::itemSelectionChanged, this, &AutoCorrectionWidget::slotEnableDisableAbreviationList);
     connect(d->ui->abbreviationList, &PimCommon::AutoCorrectionListWidget::deleteSelectedItems, this, &AutoCorrectionWidget::removeAbbreviationEntry);
     connect(d->ui->twoUpperLetterList, &PimCommon::AutoCorrectionListWidget::itemSelectionChanged, this, &AutoCorrectionWidget::slotEnableDisableTwoUpperEntry);
     connect(d->ui->twoUpperLetterList, &PimCommon::AutoCorrectionListWidget::deleteSelectedItems, this, &AutoCorrectionWidget::removeTwoUpperLetterEntry);
-    connect(d->ui->autocorrectionLanguage, SIGNAL(activated(int)), SLOT(changeLanguage(int)));
-    connect(d->ui->addNonBreakingSpaceInFrench, &QCheckBox::clicked, this, &AutoCorrectionWidget::changed);
+    connect(d->ui->autocorrectionLanguage, QOverload<int>::of(&PimCommon::AutoCorrectionLanguage::activated), this, &AutoCorrectionWidget::changeLanguage);
+    connect(d->ui->addNonBreakingSpaceInFrench, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->twoUpperLetter, &KLineEdit::returnPressed, this, &AutoCorrectionWidget::addTwoUpperLetterEntry);
     connect(d->ui->abbreviation, &KLineEdit::returnPressed, this, &AutoCorrectionWidget::addAbbreviationEntry);
     slotEnableDisableAbreviationList();
@@ -195,7 +193,6 @@ void AutoCorrectionWidget::loadAutoCorrectionAndException()
 
     d->ui->abbreviationList->clear();
     d->ui->abbreviationList->addItems(d->m_upperCaseExceptions.toList());
-
 }
 
 void AutoCorrectionWidget::addAutoCorrectEntries()
@@ -279,28 +276,30 @@ void AutoCorrectionWidget::enableDoubleQuotes(bool state)
 
 void AutoCorrectionWidget::selectSingleQuoteCharOpen()
 {
-    KPIMTextEdit::SelectSpecialCharDialog dlg(this);
-    dlg.setCurrentChar(d->m_singleQuotes.begin);
-    dlg.showSelectButton(false);
-    dlg.autoInsertChar();
-    if (dlg.exec()) {
-        d->m_singleQuotes.begin = dlg.currentChar();
+    QPointer<KPIMTextEdit::SelectSpecialCharDialog> dlg = new KPIMTextEdit::SelectSpecialCharDialog(this);
+    dlg->setCurrentChar(d->m_singleQuotes.begin);
+    dlg->showSelectButton(false);
+    dlg->autoInsertChar();
+    if (dlg->exec()) {
+        d->m_singleQuotes.begin = dlg->currentChar();
         d->ui->singleQuote1->setText(d->m_singleQuotes.begin);
         emitChanged();
     }
+    delete dlg;
 }
 
 void AutoCorrectionWidget::selectSingleQuoteCharClose()
 {
-    KPIMTextEdit::SelectSpecialCharDialog dlg(this);
-    dlg.showSelectButton(false);
-    dlg.setCurrentChar(d->m_singleQuotes.end);
-    dlg.autoInsertChar();
-    if (dlg.exec()) {
-        d->m_singleQuotes.end = dlg.currentChar();
+    QPointer<KPIMTextEdit::SelectSpecialCharDialog> dlg = new KPIMTextEdit::SelectSpecialCharDialog(this);
+    dlg->showSelectButton(false);
+    dlg->setCurrentChar(d->m_singleQuotes.end);
+    dlg->autoInsertChar();
+    if (dlg->exec()) {
+        d->m_singleQuotes.end = dlg->currentChar();
         d->ui->singleQuote2->setText(d->m_singleQuotes.end);
         emitChanged();
     }
+    delete dlg;
 }
 
 void AutoCorrectionWidget::setDefaultSingleQuotes()
@@ -313,28 +312,30 @@ void AutoCorrectionWidget::setDefaultSingleQuotes()
 
 void AutoCorrectionWidget::selectDoubleQuoteCharOpen()
 {
-    KPIMTextEdit::SelectSpecialCharDialog dlg(this);
-    dlg.showSelectButton(false);
-    dlg.setCurrentChar(d->m_doubleQuotes.begin);
-    dlg.autoInsertChar();
-    if (dlg.exec()) {
-        d->m_doubleQuotes.begin = dlg.currentChar();
+    QPointer<KPIMTextEdit::SelectSpecialCharDialog> dlg = new KPIMTextEdit::SelectSpecialCharDialog(this);
+    dlg->showSelectButton(false);
+    dlg->setCurrentChar(d->m_doubleQuotes.begin);
+    dlg->autoInsertChar();
+    if (dlg->exec()) {
+        d->m_doubleQuotes.begin = dlg->currentChar();
         d->ui->doubleQuote1->setText(d->m_doubleQuotes.begin);
         emitChanged();
     }
+    delete dlg;
 }
 
 void AutoCorrectionWidget::selectDoubleQuoteCharClose()
 {
-    KPIMTextEdit::SelectSpecialCharDialog dlg(this);
-    dlg.showSelectButton(false);
-    dlg.setCurrentChar(d->m_doubleQuotes.end);
-    dlg.autoInsertChar();
-    if (dlg.exec()) {
-        d->m_doubleQuotes.end = dlg.currentChar();
+    QPointer<KPIMTextEdit::SelectSpecialCharDialog> dlg = new KPIMTextEdit::SelectSpecialCharDialog(this);
+    dlg->showSelectButton(false);
+    dlg->setCurrentChar(d->m_doubleQuotes.end);
+    dlg->autoInsertChar();
+    if (dlg->exec()) {
+        d->m_doubleQuotes.end = dlg->currentChar();
         d->ui->doubleQuote2->setText(d->m_doubleQuotes.end);
         emitChanged();
     }
+    delete dlg;
 }
 
 void AutoCorrectionWidget::setDefaultDoubleQuotes()
@@ -457,7 +458,6 @@ void AutoCorrectionWidget::enableAddRemoveButton()
         d->ui->addButton->setEnabled(enable);
     }
     d->ui->removeButton->setEnabled(enable);
-
 }
 
 void AutoCorrectionWidget::setFindReplaceText(QTreeWidgetItem *item, int column)
@@ -519,7 +519,6 @@ void AutoCorrectionWidget::addTwoUpperLetterEntry()
     }
     slotEnableDisableTwoUpperEntry();
     d->ui->twoUpperLetter->clear();
-
 }
 
 void AutoCorrectionWidget::removeTwoUpperLetterEntry()
@@ -566,7 +565,7 @@ void AutoCorrectionWidget::slotImportAutoCorrection(QAction *act)
             filter = i18n("KMail Autocorrection File (*.xml)");
             break;
         }
-        const QString fileName = QFileDialog::getOpenFileName(this, title,  QString(), filter);
+        const QString fileName = QFileDialog::getOpenFileName(this, title, QString(), filter);
         if (!fileName.isEmpty()) {
             PimCommon::ImportAbstractAutocorrection *importAutoCorrection = nullptr;
             switch (type) {
@@ -640,10 +639,13 @@ void AutoCorrectionWidget::loadGlobalAutoCorrectionAndException()
 
 void AutoCorrectionWidget::slotExportAutoCorrection()
 {
+    if (d->mWasChanged) {
+        KMessageBox::error(this, i18n("Please save changes before exporting settings."), i18n("Export Autocorrection File"));
+        return;
+    }
     const QString saveUrl = QFileDialog::getSaveFileName(this, i18n("Export Autocorrection File"), QDir::homePath());
     if (saveUrl.isEmpty()) {
         return;
     }
     d->mAutoCorrection->writeAutoCorrectionXmlFile(saveUrl);
 }
-
