@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,29 +17,20 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <QDebug>
 #include <QStandardPaths>
 #include <QApplication>
-#include <KAboutData>
-#include <KLocalizedString>
 #include <QCommandLineParser>
-#include <QCommandLineOption>
 #include "logactivitiesmainwidget.h"
 
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("logactivities"), i18n("logactivities_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for log activities"));
     QStandardPaths::setTestModeEnabled(true);
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
 
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     LogActivitiesMainWidget *w = new LogActivitiesMainWidget;
     w->show();
