@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,9 +17,7 @@
 
 #include "translator/translatorwidget.h"
 
-#include <KLocalizedString>
 #include <QApplication>
-#include <KAboutData>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 
@@ -27,15 +25,10 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData aboutData(QStringLiteral("translator_gui"), i18n("TranslatorTest_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for translator widget"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     PimCommon::TranslatorWidget *w = new PimCommon::TranslatorWidget();
     w->show();
@@ -43,4 +36,3 @@ int main(int argc, char **argv)
     delete w;
     return 0;
 }
-
