@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   The program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,9 +23,7 @@
 #include "kpimtextedit/plaintexteditor.h"
 #include <kio/job.h>
 #include "kpimtextedit/plaintexteditorwidget.h"
-namespace PimCommon
-{
-
+namespace PimCommon {
 class TranslatorResultTextEdit : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
@@ -60,7 +58,7 @@ class PIMCOMMON_EXPORT TranslatorWidget : public QWidget
 public:
     explicit TranslatorWidget(QWidget *parent = nullptr);
     explicit TranslatorWidget(const QString &text, QWidget *parent = nullptr);
-    ~TranslatorWidget();
+    ~TranslatorWidget() override;
 
     void setTextToTranslate(const QString &);
     void writeConfig();
@@ -96,4 +94,3 @@ private:
 }
 
 #endif /* TRANSLATORWIDGET_H */
-
